/*
 * Copyright (c) 2004 Luka Frelih 
 * This is the Frida V. control panel LED setter.
 *
 * Copyright (c) 2003 The Regents of the University of California.  All 
 * rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Neither the name of the University nor the names of its
 *   contributors may be used to endorse or promote products derived
 *   from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */
 

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>

#include "parapin.h"

int pins_in[] = { 1, 11, 12, 13, 14, 15, -1};
int pins_out[] = { 2, 3, 4, 5, 6, -1};

void usage(void) {
     printf("%s", "Usage: frida-set-led NUMBER STATE. \nNumbers go from 1 to 4, state can be on or off.\n");
}

int main(int argc, char *argv[])
{
  if (pin_init_user(LPT1) < 0)
    exit(0);

  pin_output_mode(LP_DATA_PINS);
  pin_input_mode(LP_SWITCHABLE_PINS|LP_ALWAYS_INPUT_PINS);

  if (argc != 3) {
     usage();
     return 1000;
  }

  int led = atoi(argv[1]);

  if (led<1 || led>4) {
     usage();
     return 101;
  }

  if (!strcmp(argv[2],"on")) {
     set_pin(LP_PIN[pins_out[led]]);
     printf("LED %d set\n",led);
  }

  if (!strcmp(argv[2],"off")) {
     clear_pin(LP_PIN[pins_out[led]]);
     printf("LED %d cleared\n",led);
  }

  return 0;

}

