/*
 *
 * Copyright (c) 2003 The Regents of the University of California.  All 
 * rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Neither the name of the University nor the names of its
 *   contributors may be used to endorse or promote products derived
 *   from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */
 

/*
 * System-specific include files for QNX Neutrino
 */

#include <stdio.h>
#include <sys/types.h>
#include <sys/neutrino.h>
#include <hw/inout.h>
#include <sys/mman.h>
#include <inttypes.h>

/***************** QNX-Specific inb() and outb() *************************/

/* base address of parallel port I/O */
static uintptr_t mmap_handle[3];

#define INB(register_number) in8(mmap_handle[register_number])
#define OUTB(value, register_number) out8(mmap_handle[register_number], value)

/**************** QNX-specific Initialization Functions *******************/


/* user-land initialization */
int pin_init_user(int base)
{
  int i;

  /* printf("Get permissions.\n"); */
  if (ThreadCtl(_NTO_TCTL_IO, NULL) < 0) {
    printf("Failed to get permsissions.\n");
    perror("gpio");
    return -1;
  }

  for (i = 0; i < 3; i++) {
    if ((mmap_handle[i] = mmap_device_io(1, (base + i))) ==
	(_uintptr)MAP_FAILED) {
      perror("mmap");
      return -1;
    }
  }

  pin_init_internal();
  return 0;
}


